"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsDuration = exports.IS_DURATION = void 0;
const class_validator_1 = require("class-validator");
const is_duration_predicate_1 = require("./is-duration.predicate");
/** @hidden */
exports.IS_DURATION = 'isDuration';
/**
 * Checks if the given value is a valid Dayjs duration.
 *
 * A duration is considered valid if and only if:
 *   - it passes [dayjs.isDuration()](https://day.js.org/docs/en/durations/is-a-duration)
 *   - its numeric value is a finite number (i.e., `duration.asMilliseconds()` is not `NaN`)
 *   - its numeric value is non-negative
 *
 * This requires the [duration-plugin](https://day.js.org/docs/en/plugin/duration) to be loaded. If this is not the
 * case, an error will be thrown.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Dayjs duration.
 * @IsDuration()
 * value: Duration
 * ```
 *
 * @category Type
 * @param options
 * Accepts the following options (in addition to generic class-validator options):
 *   - `allow_invalid: boolean = false`
 *     If true, allow the duration to be invalid.
 */
function IsDuration(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_DURATION,
        validator: {
            validate: (value, _arguments) => (0, is_duration_predicate_1.isDuration)(value, { allow_invalid: options === null || options === void 0 ? void 0 : options.allow_invalid }),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be ${(options === null || options === void 0 ? void 0 : options.allow_invalid) ? 'a' : 'a valid'} Dayjs duration`, options),
        },
    }, options);
}
exports.IsDuration = IsDuration;
