"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsNetworkPort = exports.IS_NETWORK_PORT = void 0;
const class_validator_1 = require("class-validator");
const is_network_port_predicate_1 = require("./is-network-port.predicate");
function message({ allow_system_allocated, allow_system_ports, }) {
    return `${allow_system_allocated ? 'a' : 'a static'}${allow_system_ports ? '' : ' non-system'} network port`;
}
/** @hidden */
exports.IS_NETWORK_PORT = 'isNetworkPort';
/**
 * Checks if the given value is a valid port number.
 *
 * This is similar to the built-in `@IsPort` except that it requires the value to be a number (not a string).
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a valid network port (but not 0).
 * @IsNetworkPort({ allow_system_allocated: false })
 * remotePort: number
 * ```
 *
 * @category Number
 * @param options
 * Accepts the following options (in addition to generic class-validator options):
 *   - `allow_system_allocated: boolean = true`
 *     If true, allow port 0 (system allocated).
 *   - `allow_system_ports: boolean = true`
 *     If true, allow ports below 1024.
 */
function IsNetworkPort(options) {
    const { allow_system_allocated, allow_system_ports } = Object.assign({ allow_system_allocated: true, allow_system_ports: true }, options);
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_NETWORK_PORT,
        validator: {
            validate: (value, _arguments) => (0, is_network_port_predicate_1.isNetworkPort)(value, {
                allow_system_allocated,
                allow_system_ports,
            }),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be ${message({
                allow_system_allocated,
                allow_system_ports,
            })}`, options),
        },
    }, options);
}
exports.IsNetworkPort = IsNetworkPort;
